#
# admin.py
#
# Copyright (c) 2024 Daniel Andrlik
# All rights reserved.
#
# SPDX-License-Identifier: BSD-3-Clause
#

from django.contrib import admin

from django_quotes.models import (
    GroupStats,
    Quote,
    QuoteStats,
    Source,
    SourceGroup,
    SourceStats,
)

# Register your models here.


@admin.register(SourceGroup)
class SourceGroupAdmin(admin.ModelAdmin):
    """Model admin for SourceGroup."""

    pass


@admin.register(Source)
class SourceAdmin(admin.ModelAdmin):
    """Model admin for Source."""

    pass


@admin.register(Quote)
class QuoteAdmin(admin.ModelAdmin):
    """Model admin for Quote."""

    pass


@admin.register(GroupStats)
class GroupStatsAdmin(admin.ModelAdmin):
    """Model admin for GroupStats"""

    pass


@admin.register(SourceStats)
class SourceStatAdmin(admin.ModelAdmin):
    """Model admin for SourceStats"""

    pass


@admin.register(QuoteStats)
class QuoteStatAdmin(admin.ModelAdmin):
    """Model admin for QuoteStats"""

    pass



# Generated by Django 5.0.4 on 2024-04-03 20:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_quotes", "0004_quote_pub_date"),
    ]

    operations = [
        migrations.AlterField(
            model_name="groupmarkovmodel",
            name="created",
            field=models.DateTimeField(auto_now_add=True, help_text="Created timestamp"),
        ),
        migrations.AlterField(
            model_name="groupmarkovmodel",
            name="modified",
            field=models.DateTimeField(auto_now=True, help_text="Last modified time"),
        ),
        migrations.AlterField(
            model_name="groupstats",
            name="created",
            field=models.DateTimeField(auto_now_add=True, help_text="Created timestamp"),
        ),
        migrations.AlterField(
            model_name="groupstats",
            name="modified",
            field=models.DateTimeField(auto_now=True, help_text="Last modified time"),
        ),
        migrations.AlterField(
            model_name="quote",
            name="created",
            field=models.DateTimeField(auto_now_add=True, help_text="Created timestamp"),
        ),
        migrations.AlterField(
            model_name="quote",
            name="modified",
            field=models.DateTimeField(auto_now=True, help_text="Last modified time"),
        ),
        migrations.AlterField(
            model_name="quotestats",
            name="created",
            field=models.DateTimeField(auto_now_add=True, help_text="Created timestamp"),
        ),
        migrations.AlterField(
            model_name="quotestats",
            name="modified",
            field=models.DateTimeField(auto_now=True, help_text="Last modified time"),
        ),
        migrations.AlterField(
            model_name="source",
            name="created",
            field=models.DateTimeField(auto_now_add=True, help_text="Created timestamp"),
        ),
        migrations.AlterField(
            model_name="source",
            name="modified",
            field=models.DateTimeField(auto_now=True, help_text="Last modified time"),
        ),
        migrations.AlterField(
            model_name="sourcegroup",
            name="created",
            field=models.DateTimeField(auto_now_add=True, help_text="Created timestamp"),
        ),
        migrations.AlterField(
            model_name="sourcegroup",
            name="modified",
            field=models.DateTimeField(auto_now=True, help_text="Last modified time"),
        ),
        migrations.AlterField(
            model_name="sourcemarkovmodel",
            name="created",
            field=models.DateTimeField(auto_now_add=True, help_text="Created timestamp"),
        ),
        migrations.AlterField(
            model_name="sourcemarkovmodel",
            name="modified",
            field=models.DateTimeField(auto_now=True, help_text="Last modified time"),
        ),
        migrations.AlterField(
            model_name="sourcestats",
            name="created",
            field=models.DateTimeField(auto_now_add=True, help_text="Created timestamp"),
        ),
        migrations.AlterField(
            model_name="sourcestats",
            name="modified",
            field=models.DateTimeField(auto_now=True, help_text="Last modified time"),
        ),
    ]



# Generated by Django 5.0.4 on 2024-04-25 21:06

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        (
            "django_quotes",
            "0009_alter_source_text_model_alter_sourcegroup_text_model_squashed_0012_remove_sourcemarkovmodel_source_and_more",
        ),
    ]

    operations = [
        migrations.RemoveField(
            model_name="quote",
            name="quote_rendered",
        ),
        migrations.RemoveField(
            model_name="source",
            name="description_rendered",
        ),
        migrations.RemoveField(
            model_name="sourcegroup",
            name="description_rendered",
        ),
    ]



#
# signals.py
#
# Copyright (c) 2024 Daniel Andrlik
# All rights reserved.
#
# SPDX-License-Identifier: BSD-3-Clause
#

"""Defines signals

quote_random_retrieved is emitted when a random quote is supplied.

The `sender` should in most contexts be either `Source` or `SourceGroup`
 class definitions (**not instances**).
The `instance` should be the actual instance of the `Source` that is being used.

This signal will update the `quotes_retrieved` stats in the related ``GroupStats``,
`SourceStats`, and `QuoteStats` objects.
"""

import django.dispatch

quote_random_retrieved = django.dispatch.Signal()



# Generated by Django 4.1.1 on 2022-10-11 17:43

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_quotes", "0003_alter_source_slug_alter_sourcegroup_slug"),
    ]

    operations = [
        migrations.AddField(
            model_name="quote",
            name="pub_date",
            field=models.DateTimeField(
                blank=True,
                help_text="When is the earliest time this should appear in random results?",
                null=True,
            ),
        ),
    ]



#
# users.py
#
# Copyright (c) 2024 Daniel Andrlik
# All rights reserved.
#
# SPDX-License-Identifier: BSD-3-Clause
#

from collections.abc import Sequence
from typing import Any

from django.contrib.auth import get_user_model
from factory import Faker, post_generation
from factory.django import DjangoModelFactory


class UserFactory(DjangoModelFactory):
    username = Faker("user_name")
    email = Faker("email")
    first_name = Faker("name")

    @post_generation
    def password(self, create: bool, extracted: Sequence[Any], **kwargs):
        password = (
            extracted
            if extracted
            else Faker(
                "password",
                length=42,
                special_chars=True,
                digits=True,
                upper_case=True,
                lower_case=True,
            ).evaluate(None, None, extra={"locale": None})
        )
        self.set_password(password)

    class Meta:
        model = get_user_model()
        django_get_or_create = ["username"]
